@@ -1,12 +1,12 @@
 package App::TrimHistories;
 
-our $DATE = '2017-06-17'; # DATE
-our $VERSION = '0.003'; # VERSION
+our $DATE = '2017-06-19'; # DATE
+our $VERSION = '0.004'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any '$log';
+use Log::ger;
 
 our %SPEC;
 
@@ -132,8 +132,12 @@ sub trim_histories {
     );
 
     for my $f (@{ $res->{discard} }) {
-        my $meth = $args{-dry_run} ? "warnf" : "infof";
-        $log->$meth("%sDeleting %s ...", $args{-dry_run} ? "[DRY-RUN] " : "", $f);
+        my @log_args = ("%sDeleting %s ...", $args{-dry_run} ? "[DRY-RUN] " : "", $f);
+        if ($args{-dry_run}) {
+            log_warn @log_args;
+        } else {
+            log_info @log_args;
+        }
         unless ($args{-dry_run}) {
             unlink $f or warn "Can't delete $f: $!\n";
         }
@@ -157,7 +161,7 @@ App::TrimHistories - Keep only a certain number of sets of file histories, delet
 
 =head1 VERSION
 
-This document describes version 0.003 of App::TrimHistories (from Perl distribution App-TrimHistories), released on 2017-06-17.
+This document describes version 0.004 of App::TrimHistories (from Perl distribution App-TrimHistories), released on 2017-06-19.
 
 =head1 SYNOPSIS
 
